@@ -1,8 +1,9 @@
 """Package handling ontologies."""
-from .bto import BTO
+
 from .sbo import SBO
-from .eco import ECO
 from .kisao import KISAO
 
+# from .eco import ECO
+# from .bto import BTO
 # from .fma import FMA
 # from .go import GO
